@@ -190,6 +190,7 @@ __all__ = (
     "DiskImageFormatType",
     "DiskTypeType",
     "DnsNameStateType",
+    "DnsRecordIpTypeType",
     "DnsSupportValueType",
     "DomainTypeType",
     "EbsEncryptionSupportType",
@@ -279,6 +280,7 @@ __all__ = (
     "InterfacePermissionTypeType",
     "InterfaceProtocolTypeType",
     "InternetGatewayExistsWaiterName",
+    "IpAddressTypeType",
     "IpamAddressHistoryResourceTypeType",
     "IpamComplianceStatusType",
     "IpamManagementStateType",
@@ -366,6 +368,7 @@ __all__ = (
     "SearchTransitGatewayMulticastGroupsPaginatorName",
     "SecurityGroupExistsWaiterName",
     "SelfServicePortalType",
+    "ServiceConnectivityTypeType",
     "ServiceStateType",
     "ServiceTypeType",
     "ShutdownBehaviorType",
@@ -394,6 +397,7 @@ __all__ = (
     "TelemetryStatusType",
     "TenancyType",
     "TieringOperationStatusType",
+    "TpmSupportValuesType",
     "TrafficDirectionType",
     "TrafficMirrorFilterRuleFieldType",
     "TrafficMirrorNetworkServiceType",
@@ -731,6 +735,7 @@ DeviceTypeType = Literal["ebs", "instance-store"]
 DiskImageFormatType = Literal["RAW", "VHD", "VMDK"]
 DiskTypeType = Literal["hdd", "ssd"]
 DnsNameStateType = Literal["failed", "pendingVerification", "verified"]
+DnsRecordIpTypeType = Literal["dualstack", "ipv4", "ipv6", "service-defined"]
 DnsSupportValueType = Literal["disable", "enable"]
 DomainTypeType = Literal["standard", "vpc"]
 EbsEncryptionSupportType = Literal["supported", "unsupported"]
@@ -832,6 +837,8 @@ ImageAttributeNameType = Literal[
     "productCodes",
     "ramdisk",
     "sriovNetSupport",
+    "tpmSupport",
+    "uefiData",
 ]
 ImageAvailableWaiterName = Literal["image_available"]
 ImageExistsWaiterName = Literal["image_exists"]
@@ -1065,6 +1072,13 @@ InstanceTypeType = Literal[
     "i3en.large",
     "i3en.metal",
     "i3en.xlarge",
+    "i4i.16xlarge",
+    "i4i.2xlarge",
+    "i4i.32xlarge",
+    "i4i.4xlarge",
+    "i4i.8xlarge",
+    "i4i.large",
+    "i4i.xlarge",
     "im4gn.16xlarge",
     "im4gn.2xlarge",
     "im4gn.4xlarge",
@@ -1390,6 +1404,7 @@ InstanceTypeType = Literal[
 InterfacePermissionTypeType = Literal["EIP-ASSOCIATE", "INSTANCE-ATTACH"]
 InterfaceProtocolTypeType = Literal["GRE", "VLAN"]
 InternetGatewayExistsWaiterName = Literal["internet_gateway_exists"]
+IpAddressTypeType = Literal["dualstack", "ipv4", "ipv6"]
 IpamAddressHistoryResourceTypeType = Literal[
     "eip", "instance", "network-interface", "subnet", "vpc"
 ]
@@ -1416,9 +1431,12 @@ IpamPoolStateType = Literal[
     "delete-complete",
     "delete-failed",
     "delete-in-progress",
+    "isolate-complete",
+    "isolate-in-progress",
     "modify-complete",
     "modify-failed",
     "modify-in-progress",
+    "restore-in-progress",
 ]
 IpamResourceTypeType = Literal["eip", "ipv6-pool", "public-ipv4-pool", "subnet", "vpc"]
 IpamScopeStateType = Literal[
@@ -1428,9 +1446,12 @@ IpamScopeStateType = Literal[
     "delete-complete",
     "delete-failed",
     "delete-in-progress",
+    "isolate-complete",
+    "isolate-in-progress",
     "modify-complete",
     "modify-failed",
     "modify-in-progress",
+    "restore-in-progress",
 ]
 IpamScopeTypeType = Literal["private", "public"]
 IpamStateType = Literal[
@@ -1440,9 +1461,12 @@ IpamStateType = Literal[
     "delete-complete",
     "delete-failed",
     "delete-in-progress",
+    "isolate-complete",
+    "isolate-in-progress",
     "modify-complete",
     "modify-failed",
     "modify-in-progress",
+    "restore-in-progress",
 ]
 Ipv6SupportValueType = Literal["disable", "enable"]
 KeyFormatType = Literal["pem", "ppk"]
@@ -1652,6 +1676,7 @@ SearchTransitGatewayMulticastGroupsPaginatorName = Literal[
 ]
 SecurityGroupExistsWaiterName = Literal["security_group_exists"]
 SelfServicePortalType = Literal["disabled", "enabled"]
+ServiceConnectivityTypeType = Literal["ipv4", "ipv6"]
 ServiceStateType = Literal["Available", "Deleted", "Deleting", "Failed", "Pending"]
 ServiceTypeType = Literal["Gateway", "GatewayLoadBalancer", "Interface"]
 ShutdownBehaviorType = Literal["stop", "terminate"]
@@ -1703,6 +1728,7 @@ TieringOperationStatusType = Literal[
     "temporary-restore-failed",
     "temporary-restore-in-progress",
 ]
+TpmSupportValuesType = Literal["v2.0"]
 TrafficDirectionType = Literal["egress", "ingress"]
 TrafficMirrorFilterRuleFieldType = Literal[
     "description", "destination-port-range", "protocol", "source-port-range"
@@ -1710,7 +1736,9 @@ TrafficMirrorFilterRuleFieldType = Literal[
 TrafficMirrorNetworkServiceType = Literal["amazon-dns"]
 TrafficMirrorRuleActionType = Literal["accept", "reject"]
 TrafficMirrorSessionFieldType = Literal["description", "packet-length", "virtual-network-id"]
-TrafficMirrorTargetTypeType = Literal["network-interface", "network-load-balancer"]
+TrafficMirrorTargetTypeType = Literal[
+    "gateway-load-balancer-endpoint", "network-interface", "network-load-balancer"
+]
 TrafficTypeType = Literal["ACCEPT", "ALL", "REJECT"]
 TransitGatewayAssociationStateType = Literal[
     "associated", "associating", "disassociated", "disassociating"
